@@ -1,10 +1,32 @@
 """ ARC Computing Element
-    Using the ARC API now
+
+Leverage the arc Python library to interact with ARC gridftp services.
 
 **Configuration Parameters**
 
 Configuration for the ARCComputingElement submission can be done via the configuration system.
 
+ARCLogLevel:
+   Log level of the ARC logging library. Possible values are: `DEBUG`, `VERBOSE`, `INFO`, `WARNING`, `ERROR`, `FATAL`
+
+EndpointType:
+   Name of the protocol to use to interact with ARC services: Emies and Gridftp are supported.
+   Gridftp communicates with gridftpd services providing authentication and encryption for file transfers.
+   ARC developers are going to drop it in the future.
+   Emies is another protocol that allows to interact with A-REX services that provide additional features
+   (support of OIDC tokens).
+
+Host:
+   The host for the ARC CE, used to overwrite the CE name.
+
+Preamble:
+   Line that should be executed just before the executable file.
+
+WorkingDirectory:
+   Directory where the pilot log files are stored locally. For instance::
+
+     /opt/dirac/pro/runit/WorkloadManagement/SiteDirectorArc
+
 XRSLExtraString:
    Default additional string for ARC submit files. Should be written in the following format::
 
@@ -15,24 +37,6 @@ XRSLMPExtraString:
 
      (key = "value")
 
-Host:
-   The host for the ARC CE, used to overwrite the CE name.
-
-WorkingDirectory:
-   Directory where the pilot log files are stored locally. For instance::
-
-     /opt/dirac/pro/runit/WorkloadManagement/SiteDirectorArc
-
-EndpointType:
-   Name of the protocol to use to interact with ARC services: Emies and Gridftp are supported.
-   Gridftp communicates with gridftpd services providing authentication and encryption for file transfers.
-   ARC developers are going to drop it in the future.
-   Emies is another protocol that allows to interact with A-REX services that provide additional features
-   (support of OIDC tokens).
-
-Preamble:
-   Line that should be executed just before the executable file.
-
 **Code Documentation**
 """
 import os
@@ -52,20 +56,29 @@ from DIRAC.WorkloadManagementSystem.Client import PilotStatus
 
 
 MANDATORY_PARAMETERS = ["Queue"]  # Mandatory for ARC CEs in GLUE2?
+# See https://www.nordugrid.org/arc/arc6/tech/rest/rest.html#rest-interface-job-states
+# We let "Deleted, Hold, Undefined" for the moment as we are not sure whether they are still used
 STATES_MAP = {
+    "Accepting": PilotStatus.WAITING,
     "Accepted": PilotStatus.WAITING,
     "Preparing": PilotStatus.WAITING,
+    "Prepared": PilotStatus.WAITING,
     "Submitting": PilotStatus.WAITING,
     "Queuing": PilotStatus.WAITING,
-    "Undefined": PilotStatus.UNKNOWN,
     "Running": PilotStatus.RUNNING,
+    "Held": PilotStatus.RUNNING,
+    "Exitinglrms": PilotStatus.RUNNING,
+    "Other": PilotStatus.RUNNING,
+    "Executed": PilotStatus.RUNNING,
     "Finishing": PilotStatus.RUNNING,
-    "Deleted": PilotStatus.ABORTED,
-    "Killed": PilotStatus.ABORTED,
-    "Failed": PilotStatus.FAILED,
-    "Hold": PilotStatus.FAILED,
     "Finished": PilotStatus.DONE,
-    "Other": PilotStatus.DONE,
+    "Failed": PilotStatus.FAILED,
+    "Killing": PilotStatus.ABORTED,
+    "Killed": PilotStatus.ABORTED,
+    "Wiped": PilotStatus.ABORTED,
+    "Deleted": PilotStatus.ABORTED,
+    "Hold": PilotStatus.FAILED,
+    "Undefined": PilotStatus.UNKNOWN,
 }
 
 
@@ -82,6 +95,7 @@ class ARCComputingElement(ComputingElement):
         self.mandatoryParameters = MANDATORY_PARAMETERS
         self.pilotProxy = ""
         self.queue = ""
+        self.arcQueue = ""
         self.gridEnv = ""
         self.ceHost = self.ceName
         self.endpointType = "Gridftp"
@@ -224,7 +238,11 @@ class ARCComputingElement(ComputingElement):
 
     #############################################################################
     def _reset(self):
+        # Assume that the ARC queues are always of the format nordugrid-<batchSystem>-<queue>
+        # And none of our supported batch systems have a "-" in their name
         self.queue = self.ceParameters.get("CEQueueName", self.ceParameters["Queue"])
+        self.arcQueue = self.queue.split("-", 2)[2]
+
         self.ceHost = self.ceParameters.get("Host", self.ceHost)
         self.gridEnv = self.ceParameters.get("GridEnv", self.gridEnv)
 
@@ -262,10 +280,6 @@ class ARCComputingElement(ComputingElement):
     #############################################################################
     def submitJob(self, executableFile, proxy, numberOfJobs=1, inputs=None, outputs=None):
         """Method to submit job"""
-
-        # Assume that the ARC queues are always of the format nordugrid-<batchSystem>-<queue>
-        # And none of our supported batch systems have a "-" in their name
-        self.arcQueue = self.queue.split("-", 2)[2]
         result = self._prepareProxy()
         if not result["OK"]:
             self.log.error("ARCComputingElement: failed to set up proxy", result["Message"])
@@ -445,7 +459,7 @@ class ARCComputingElement(ComputingElement):
                 return res
             cmd1 = "ldapsearch -x -o ldif-wrap=no -LLL -H ldap://%s:2135  -b 'o=glue' " % self.ceHost
             cmd2 = '"(&(objectClass=GLUE2MappingPolicy)(GLUE2PolicyRule=vo:%s))"' % vo.lower()
-            cmd3 = " | grep GLUE2MappingPolicyShareForeignKey | grep %s" % (self.queue.split("-")[-1])
+            cmd3 = " | grep GLUE2MappingPolicyShareForeignKey | grep %s" % (self.arcQueue)
             cmd4 = " | sed 's/GLUE2MappingPolicyShareForeignKey: /GLUE2ShareID=/' "
             cmd5 = " | xargs -L1 ldapsearch -x -o ldif-wrap=no -LLL -H ldap://%s:2135 -b 'o=glue' " % self.ceHost
             cmd6 = " | egrep '(ShareWaiting|ShareRunning)'"
