@@ -6,29 +6,30 @@ For a given IP/host it will send jobs directly through ssh
 
 Configuration for the SSHComputingElement submission can be done via the configuration system.
 
-BatchSystem:
-   Underlying batch system that is going to be used to orchestrate executable files. The Batch System has to be
-   accessible from the LocalCE. By default, the LocalComputingElement submits directly on the host via the Host class.
-
-SharedArea:
-   Area used to store executable/output/error files if they are not aready defined via BatchOutput, BatchError,
-   InfoArea, ExecutableArea and/or WorkArea. The path should be absolute.
+BatchError:
+   Area where the job errors are stored.
+   If not defined: SharedArea + '/data' is used.
+   If not absolute: SharedArea + path is used.
 
 BatchOutput:
    Area where the job outputs are stored.
    If not defined: SharedArea + '/data' is used.
    If not absolute: SharedArea + path is used.
 
-BatchError:
-   Area where the job errors are stored.
-   If not defined: SharedArea + '/data' is used.
-   If not absolute: SharedArea + path is used.
+BatchSystem:
+   Underlying batch system that is going to be used to orchestrate executable files. The Batch System has to be
+   remotely accessible. By default, the SSHComputingElement submits directly on the host via the Host class.
+   Available batch systems are defined in :mod:`~DIRAC.Resources.Computing.BatchSystems`.
 
 ExecutableArea:
    Area where the executable files are stored if necessary.
    If not defined: SharedArea + '/data' is used.
    If not absolute: SharedArea + path is used.
 
+SharedArea:
+   Area used to store executable/output/error files if they are not aready defined via BatchOutput, BatchError,
+   InfoArea, ExecutableArea and/or WorkArea. The path should be absolute.
+
 SSHHost:
    SSH host name
 
@@ -45,7 +46,11 @@ SSHKey:
    Location of the ssh private key for no-password connection
 
 SSHOptions:
-   Any other SSH options to be used
+   Any other SSH options to be used. Example::
+
+     SSHOptions = -o UserKnownHostsFile=/local/path/to/known_hosts
+
+   Allows to have a local copy of the ``known_hosts`` file, independent of the HOME directory.
 
 SSHTunnel:
    String defining the use of intermediate SSH host. Example::
@@ -56,7 +61,6 @@ SSHType:
    SSH (default) or gsissh
 
 **Code Documentation**
-
 """
 import os
 import json
@@ -341,9 +345,6 @@ class SSHComputingElement(ComputingElement):
         # First assure that any global parameters are loaded
         ComputingElement._addCEConfigDefaults(self)
         # Now batch system specific ones
-        if "ExecQueue" not in self.ceParameters:
-            self.ceParameters["ExecQueue"] = self.ceParameters.get("Queue", "")
-
         if "SharedArea" not in self.ceParameters:
             # . isn't a good location, move to $HOME
             self.ceParameters["SharedArea"] = "$HOME"
@@ -363,24 +364,18 @@ class SSHComputingElement(ComputingElement):
         if "WorkArea" not in self.ceParameters:
             self.ceParameters["WorkArea"] = "work"
 
-    def _reset(self):
-        """Process CE parameters and make necessary adjustments"""
+    def _getBatchSystem(self):
+        """Load a Batch System instance from the CE Parameters"""
         batchSystemName = self.ceParameters.get("BatchSystem", "Host")
         if "BatchSystem" not in self.ceParameters:
             self.ceParameters["BatchSystem"] = batchSystemName
         result = self.loadBatchSystem(batchSystemName)
         if not result["OK"]:
             self.log.error("Failed to load the batch system plugin", batchSystemName)
-            return result
-
-        self.user = self.ceParameters["SSHUser"]
-        self.queue = self.ceParameters["Queue"]
-        self.submitOptions = self.ceParameters.get("SubmitOptions", "")
-        if "ExecQueue" not in self.ceParameters or not self.ceParameters["ExecQueue"]:
-            self.ceParameters["ExecQueue"] = self.ceParameters.get("Queue", "")
-        self.execQueue = self.ceParameters["ExecQueue"]
-        self.log.info("Using queue: ", self.queue)
+        return result
 
+    def _getBatchSystemDirectoryLocations(self):
+        """Get names of the locations to store outputs, errors, info and executables."""
         self.sharedArea = self.ceParameters["SharedArea"]
         self.batchOutput = self.ceParameters["BatchOutput"]
         if not self.batchOutput.startswith("/"):
@@ -398,13 +393,21 @@ class SSHComputingElement(ComputingElement):
         if not self.workArea.startswith("/"):
             self.workArea = os.path.join(self.sharedArea, self.workArea)
 
-        self.account = self.ceParameters.get("Account", "")
-        self.removeOutput = True
-        if "RemoveOutput" in self.ceParameters:
-            if self.ceParameters["RemoveOutput"].lower() in ["no", "false", "0"]:
-                self.removeOutput = False
+    def _reset(self):
+        """Process CE parameters and make necessary adjustments"""
+        result = self._getBatchSystem()
+        if not result["OK"]:
+            return result
+        self._getBatchSystemDirectoryLocations()
+
+        self.user = self.ceParameters["SSHUser"]
+        self.queue = self.ceParameters["Queue"]
+        self.log.info("Using queue: ", self.queue)
+
+        self.submitOptions = self.ceParameters.get("SubmitOptions", "")
         self.preamble = self.ceParameters.get("Preamble", "")
 
+        self.account = self.ceParameters.get("Account", "")
         result = self._prepareRemoteHost()
         if not result["OK"]:
             return result
@@ -467,21 +470,6 @@ class SSHComputingElement(ComputingElement):
             self.log.warn("Failed removing the generated control script locally")
             return S_ERROR("Failed removing the generated control script locally")
 
-        # Chmod the control scripts
-        # self.log.verbose( 'Chmod +x control script' )
-        # result = ssh.sshCall( 10, "chmod +x %s/%s" % ( self.sharedArea, self.controlScript ) )
-        # if not result['OK']:
-        #  self.log.warn( 'Failed chmod control script: %s' % result['Message'][1] )
-        #  return result
-        # status, output, _error = result['Value']
-        # if status != 0:
-        #  if status == -1:
-        #    self.log.warn( 'Timeout while chmod control script' )
-        #    return S_ERROR( 'Timeout while chmod control script' )
-        #  else:
-        #    self.log.warn( 'Failed uploading chmod script: %s' % output )
-        #    return S_ERROR( 'Failed uploading chmod script' )
-
         return S_OK()
 
     def _generateControlScript(self):
@@ -548,6 +536,7 @@ class SSHComputingElement(ComputingElement):
                 index = output.index("============= Start output ===============")
                 output = output[index + 42 :]
             except Exception:
+                self.log.exception("Invalid output from remote command", output)
                 return S_ERROR("Invalid output from remote command: %s" % output)
             try:
                 output = unquote(output)
@@ -733,10 +722,12 @@ class SSHComputingElement(ComputingElement):
 
         return S_OK(resultDict)
 
-    def _getJobOutputFiles(self, jobID, host=None):
+    def _getJobOutputFiles(self, jobID):
         """Get output file names for the specific CE"""
         jobStamp = os.path.basename(urlparse(jobID).path)
-        host = urlparse(jobID).hostname
+        # host can be retrieved from the path of the jobID
+        # it might not be present, in this case host is an empty string and will be defined by the CE parameters later
+        host = os.path.dirname(urlparse(jobID).path).lstrip("/")
 
         if "OutputTemplate" in self.ceParameters:
             self.outputTemplate = self.ceParameters["OutputTemplate"]
@@ -803,19 +794,19 @@ class SSHComputingElement(ComputingElement):
         host = host.split("/")[0]
 
         ssh = SSH(host=host, parameters=self.ceParameters)
-        result = ssh.scpCall(30, localOutputFile, outputFile, upload=False)
-        if not result["OK"]:
-            return result
+        resultStdout = ssh.scpCall(30, localOutputFile, outputFile, upload=False)
+        if not resultStdout["OK"]:
+            return resultStdout
 
-        result = ssh.scpCall(30, localErrorFile, errorFile, upload=False)
-        if not result["OK"]:
-            return result
+        resultStderr = ssh.scpCall(30, localErrorFile, errorFile, upload=False)
+        if not resultStderr["OK"]:
+            return resultStderr
 
         if localDir:
             output = localOutputFile
             error = localErrorFile
         else:
-            output = result["Value"][1]
-            error = result["Value"][1]
+            output = resultStdout["Value"][1]
+            error = resultStderr["Value"][1]
 
         return S_OK((output, error))
