@@ -25,6 +25,7 @@ from DIRAC.Core.Utilities.TimeUtilities import toEpochMilliSeconds
 from DIRAC.Resources.Storage.StorageFactory import StorageFactory
 from DIRAC.Core.Utilities.Pfn import pfnparse
 from DIRAC.Core.Utilities.SiteSEMapping import getSEsForSite
+from DIRAC.Core.Utilities.Network import getFQDN
 from DIRAC.Core.Security.Locations import getProxyLocation
 from DIRAC.Core.Security.ProxyInfo import getVOfromProxyGroup
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
@@ -119,7 +120,6 @@ class StorageElementItem:
       removeFile( lfn )
       prestageFile( lfn, lifetime = 86400 )
       prestageFileStatus( lfn )
-      pinFile( lfn, lifetime = 60 * 60 * 24 )
       releaseFile( lfn )
       isDirectory( lfn )
       getDirectoryMetadata( lfn )
@@ -149,7 +149,6 @@ class StorageElementItem:
         "removeFile": "removeFile",
         "prestageFile": "prestageFile",
         "prestageFileStatus": "prestageFileStatus",
-        "pinFile": "pinFile",
         "releaseFile": "releaseFile",
         "isDirectory": "isDirectory",
         "getDirectoryMetadata": "getDirectoryMetadata",
@@ -166,7 +165,6 @@ class StorageElementItem:
         "putFile": {"sourceSize": 0},
         "getFile": {"localPath": False},
         "prestageFile": {"lifetime": 86400},
-        "pinFile": {"lifetime": 60 * 60 * 24},
         "removeDirectory": {"recursive": False},
         "getDirectory": {"localPath": False},
     }
@@ -1442,6 +1440,7 @@ class StorageElementItem:
                             "Protocol": accountingDict["Protocol"],
                             "Error": str(errorMsg),
                             "Component": "StorageElement",
+                            "Hostname": getFQDN(),
                         }
                         failedRecords.append(failedRecord)
                 res = self.dataOpSender.sendData(
